use leptos::*;

use super::{
    Tag,
    Timeline,
    TimelineElement,
    TimelineLabel,
    TimelineCard,
    TimelineCardSummary,
    TimelineCardTag,
    TimelineCardContent,
    ProjectList,
    ProjectElement
};

// // Other
// const REACT_TAG = <Tag name="React" url="https://fr.legacy.reactjs.org/" />
// const SYMFONY_4_TAG = <Tag name="Symfony" url="https://symfony.com/" />
// const FLUTTER_TAG = <Tag name="Flutter" url="https://flutter.dev/" />
// const RUBY_ON_RAILS_TAG = <Tag name="Ruby on rails" url="https://rubyonrails.org/" />
// const HOTWIRED_TAG = <Tag name="Hotwired" url="https://hotwired.dev/" />
// const DOCKER_TAG = <Tag name="Docker" url="https://www.docker.com/" />
// const STEAM_TAG = <Tag name="Steam API" url="https://partner.steamgames.com/doc/sdk/api/example" />
// const GITLAB_CI_TAG = <Tag name="Gitlab CI" url="https://docs.gitlab.com/ee/ci/" />
// const UNITY_TAG = <Tag name="Unity 3D" url="https://unity.com/fr" />
// const WORDPRESS_TAG = <Tag name="Wordpress" url="https://wordpress.com/fr/" />
// const CORDOVA_TAG = <Tag name="Cordova" url="https://cordova.apache.org/" />
// const ELECTRON_TAG = <Tag name="Electron" url="https://www.electronjs.org/" />
// const LWJGL_TAG = <Tag name="LWJGL" url="https://www.lwjgl.org/" />
// const OPENGL_TAG = <Tag name="OpenGL" url="https://www.opengl.org/" />
// const VULKAN_TAG = <Tag name="Vulkan" url="https://www.vulkan.org/" />
// const MIDI_TAG = <Tag name="MIDI" url="https://fr.wikipedia.org/wiki/Musical_Instrument_Digital_Interface" />
// const REQUIREJS_TAG = <Tag name="RequireJS" url="https://requirejs.org/" />
// const WEBPACK_TAG = <Tag name="Webpack" url="https://webpack.js.org/" />
// const VITE_TAG = <Tag name="Vite" url="https://vitejs.dev/" />
// const MAVEN_TAG = <Tag name="Maven" url="https://maven.apache.org/" />
// const GRADLE_TAG = <Tag name="Gradle" url="https://gradle.org/" />
// const BABYLONJG_TAG = <Tag name="BabylonJS" url="https://www.babylonjs.com/" />
// const ROCKET_RS_TAG = <Tag name="Rocket" url="https://rocket.rs/" />
// const ACTIX_WEB_TAG = <Tag name="Actix Web" url="https://actix.rs/" />

#[derive(Copy, Clone)]
struct Lang<'a> {
    pub lang : &'a str,
    pub url : &'a str,
}

impl<'a> IntoView for Lang<'a> {
    fn into_view(self) -> View {
        let url = self.url.to_string();
        let lang = self.lang.to_string();
        view! {
            <Tag url=url>
            { lang }
            </Tag>
        }
    }
}

// Lang
const RUST_TAG : Lang<'static> = Lang { lang: "Rust", url: "https://www.rust-lang.org/" };
const JAVA_TAG : Lang<'static> = Lang { lang: "Java", url: "https://www.java.com/fr/" };
const CPP_TAG : Lang<'static> = Lang { lang: "C++", url: "https://isocpp.org/" };

// Other
const REACT_TAG : Lang<'static> = Lang { lang: "React", url: "https://fr.legacy.reactjs.org/" };
const SYMFONY_4_TAG : Lang<'static> = Lang { lang: "Symfony", url: "https://symfony.com/" };
const FLUTTER_TAG : Lang<'static> = Lang { lang: "Flutter", url: "https://flutter.dev/" };
const RUBY_ON_RAILS_TAG : Lang<'static> = Lang { lang: "Ruby on rails", url: "https://rubyonrails.org/" };
const HOTWIRED_TAG : Lang<'static> = Lang { lang: "Hotwired", url: "https://hotwired.dev/" };
const DOCKER_TAG : Lang<'static> = Lang { lang: "Docker", url: "https://www.docker.com/" };
const STEAM_TAG : Lang<'static> = Lang { lang: "Steam API", url: "https://partner.steamgames.com/doc/sdk/api/example" };
const GITLAB_CI_TAG : Lang<'static> = Lang { lang: "Gitlab CI", url: "https://docs.gitlab.com/ee/ci/" };
const UNITY_TAG : Lang<'static> = Lang { lang: "Unity 3D", url: "https://unity.com/fr" };
const WORDPRESS_TAG : Lang<'static> = Lang { lang: "Wordpress", url: "https://wordpress.com/fr/" };
const CORDOVA_TAG : Lang<'static> = Lang { lang: "Cordova", url: "https://cordova.apache.org/" };
const ELECTRON_TAG : Lang<'static> = Lang { lang: "Electron", url: "https://www.electronjs.org/" };
const LWJGL_TAG : Lang<'static> = Lang { lang: "LWJGL", url: "https://www.lwjgl.org/" };
const OPENGL_TAG : Lang<'static> = Lang { lang: "OpenGL", url: "https://www.opengl.org/" };
const VULKAN_TAG : Lang<'static> = Lang { lang: "Vulkan", url: "https://www.vulkan.org/" };
const MIDI_TAG : Lang<'static> = Lang { lang: "MIDI", url: "https://fr.wikipedia.org/wiki/Musical_Instrument_Digital_Interface" };
const REQUIREJS_TAG : Lang<'static> = Lang { lang: "RequireJS", url: "https://requirejs.org/" };
const WEBPACK_TAG : Lang<'static> = Lang { lang: "Webpack", url: "https://webpack.js.org/" };
const VITE_TAG : Lang<'static> = Lang { lang: "Vite", url: "https://vitejs.dev/" };
const MAVEN_TAG : Lang<'static> = Lang { lang: "Maven", url: "https://maven.apache.org/" };
const GRADLE_TAG : Lang<'static> = Lang { lang: "Gradle", url: "https://gradle.org/" };
const BABYLONJS_TAG : Lang<'static> = Lang { lang: "BabylonJS", url: "https://www.babylonjs.com/" };
const ROCKET_RS_TAG : Lang<'static> = Lang { lang: "Rocket", url: "https://rocket.rs/" };
const ACTIX_WEB_TAG : Lang<'static> = Lang { lang: "Actix Web", url: "https://actix.rs/" };
const LEPTOS_TAG : Lang<'static> = Lang { lang: "Leptos", url: "https://leptos.dev/" };


#[component]
pub fn MonParcours() -> impl IntoView {
    view! {
        <div>
            <Timeline>
                <TimelineElement slot:elements>
                    <TimelineLabel slot:labels>r"2019 - Aujourd’hui"</TimelineLabel>
                    <TimelineCard slot:cards>
                        <TimelineCardSummary slot:titles>
                            <TimelineCardTag slot:tags>{ REACT_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ SYMFONY_4_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ FLUTTER_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ RUBY_ON_RAILS_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ HOTWIRED_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ RUST_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ WEBPACK_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ VITE_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ GRADLE_TAG }</TimelineCardTag>
                            r"Développeur d’application Web, Mobile et Système (CDI)"
                        </TimelineCardSummary>
                        <TimelineCardContent slot:cards>
                            <p>r"Développement d’application Symfony, React, Flutter, Rust et Ruby on rails (6 et 7) pour des clients."</p><br />
                            <p>r"Je développe surtout des applications Flutter et Ruby on rails avec l’aide de Hotwired."</p><br />

                            <i>Unova France</i><br />
                            <i>11 Septembre 2019 - Toujours en CDI</i>
                        </TimelineCardContent>
                    </TimelineCard>
                    <TimelineCard slot:cards>
                        <TimelineCardSummary slot:titles>
                            <TimelineCardTag slot:tags>{ RUST_TAG }</TimelineCardTag>
                            <TimelineCardTag slot:tags>{ VULKAN_TAG }</TimelineCardTag>
                            r"Développement 3D (Perso)"
                        </TimelineCardSummary>
                        <TimelineCardContent slot:cards>
                            <p>Je développe un petit moteur 3D pour apprendre à utiliser Vulkan, mais aussi pour prendre en expérience en Rust</p><br/>

                            <ProjectList>
                                <ProjectElement url="https://github.com/mrdev023/RustGameMicroEngine".to_string()>Projet pour apprendre</ProjectElement>
                                <ProjectElement url="https://github.com/mrdev023/voxel_rust_test".to_string()>Le but, refaire mon vieux projet de voxel pour progresser en Rust et Vulkan</ProjectElement>
                            </ProjectList>
                        </TimelineCardContent>
                    </TimelineCard>
                </TimelineElement>
            </Timeline>
        </div>
    }
}